Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(232)

Unified Diff: content/browser/renderer_host/video_capture_host.h

Issue 7101001: move EventHandler out of VideoCaptureController to make VS2005 happy (Closed) Base URL: svn://chrome-svn/chrome/trunk/src/
Patch Set: use default constructor Created 9 years, 7 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
Index: content/browser/renderer_host/video_capture_host.h
===================================================================
--- content/browser/renderer_host/video_capture_host.h (revision 87397)
+++ content/browser/renderer_host/video_capture_host.h (working copy)
@@ -44,7 +44,7 @@
#include "ipc/ipc_message.h"
class VideoCaptureHost : public BrowserMessageFilter,
- public VideoCaptureController::EventHandler {
+ public VideoCaptureControllerEventHandler {
public:
VideoCaptureHost();
@@ -54,16 +54,16 @@
virtual bool OnMessageReceived(const IPC::Message& message,
bool* message_was_ok);
- // VideoCaptureController::EventHandler implementation.
- virtual void OnError(VideoCaptureController::ControllerId id);
- virtual void OnBufferReady(VideoCaptureController::ControllerId id,
+ // VideoCaptureControllerEventHandler implementation.
+ virtual void OnError(const VideoCaptureControllerID& id);
+ virtual void OnBufferReady(const VideoCaptureControllerID& id,
TransportDIB::Handle handle,
base::Time timestamp);
- virtual void OnFrameInfo(VideoCaptureController::ControllerId id,
+ virtual void OnFrameInfo(const VideoCaptureControllerID& id,
int width,
int height,
int frame_per_second);
- virtual void OnReadyToDelete(VideoCaptureController::ControllerId id);
+ virtual void OnReadyToDelete(const VideoCaptureControllerID& id);
private:
friend class BrowserThread;
@@ -95,7 +95,7 @@
// Called on the IO thread when VideoCaptureController have
// reported that all DIBs have been returned.
- void DoDeleteVideoCaptureController(VideoCaptureController::ControllerId id);
+ void DoDeleteVideoCaptureController(const VideoCaptureControllerID& id);
// Send a filled buffer to the VideoCaptureMessageFilter.
void DoSendFilledBuffer(int32 routing_id,
@@ -114,10 +114,10 @@
// Handle error coming from VideoCaptureDevice.
void DoHandleError(int32 routing_id, int device_id);
- typedef std::map<VideoCaptureController::ControllerId,
+ typedef std::map<VideoCaptureControllerID,
scoped_refptr<VideoCaptureController> >EntryMap;
// A map of VideoCaptureController::ControllerId to VideoCaptureController
// objects that is currently active.
EntryMap entries_;
@@ -114,10 +114,10 @@
scoped_refptr<VideoCaptureController> >EntryMap;
- // A map of VideoCaptureController::ControllerId to VideoCaptureController
+ // A map of VideoCaptureControllerID to VideoCaptureController
// objects that is currently active.
EntryMap entries_;

Powered by Google App Engine
This is Rietveld 408576698